@@ -135,36 +135,36 @@ class Logger():
 	def __init__(self:str, name:str):
 		self.name = name.upper()
 
-	def send_error(message:str, filename:str, willprint:bool=True):
+	def send_error(self, message:str, filename:str, willprint:bool=True):
 		self.message = message
 		self.filename = filename
 		self.willprint = willprint
-		append_file(self.filename, f'{self.name} --> {self.level} --> + {self.message}')
+		append_file(self.filename, f'{self.name} --> ERROR --> + {self.message}')
 		if willprint == True:
-			print(Fore.YELLOW + self.name + ' --> ' + self.level + ' --> ' + self.message + Fore.RESET)
+			print(Fore.YELLOW + self.name + ' --> ' + 'ERROR' + ' --> ' + self.message + Fore.RESET)
 		else:
 			pass
 
-	def send_warning(message:str, filename:str, willprint:bool=True):
+	def send_warning(self, message:str, filename:str, willprint:bool=True):
 		self.message = message
 		self.filename = filename
 		self.willprint = willprint
-		append_file(self.filename, f'{self.name} --> {self.level} --> + {self.message}')
+		append_file(self.filename, f'{self.name} --> WARNING --> + {self.message}')
 		if willprint == True:
 			# Red In Colorama print(Fore.RED + self.name + ' --> ' + self.level + ' --> ' + self.message + Fore.RESET)
 			fg.orange = Style(RgbFg(255, 150, 50))
-			text = fg.orange + self.name + ' --> ' + self.level + ' --> ' + self.message + fg.rs
+			text = fg.orange + self.name + ' --> ' + 'WARNING' + ' --> ' + self.message + fg.rs
 			print(text)
 		else:
 			pass
 
-	def send_critical(message:str, filename:str, willprint:bool=True):
+	def send_critical(self, message:str, filename:str, willprint:bool=True):
 		self.message = message
 		self.filename = filename
 		self.willprint = willprint
-		append_file(self.filename, f'{self.name} --> {self.level} --> + {self.message}')
+		append_file(self.filename, f'{self.name} --> CRITICAL --> + {self.message}')
 		if self.willprint == True:
-			print(Fore.RED + self.name + ' --> ' + self.level + ' --> ' + self.message + Fore.RESET)
+			print(Fore.RED + self.name + ' --> ' + 'CRITICAL' + ' --> ' + self.message + Fore.RESET)
 		else:
 			pass
 
